@@ -1,4 +1,5 @@
-import requests             # Image Uploading
+import requests
+from requests import Response
 
 #region: Image Uploading
 def upload_image(file_path, endpoint, token):
@@ -26,14 +27,15 @@ def upload_image(file_path, endpoint, token):
 
         response = requests.post(url=endpoint, headers=headers, files=form)
 
-        # # DEBUGGING: Uncomment this to print the request to a file (similar to saving a network request in Chrome) for review.
-        # with open('temp/request.txt','w') as request_file:
-        #     request_file.write('{}\n{}\r\n{}\r\n\r\n{}'.format(
-        #         '-----------START-----------',
-        #         response.request.method + ' ' + response.request.url,
-        #         '\r\n'.join('{}: {}'.format(k, v) for k, v in response.request.headers.items()),
-        #         response.request.body,
-        #     ))
-
         return(response.text)
 #endregion
+
+def log_request(r: Response, filename: str = 'temp/request.log'):
+    """For debugging only.  This will save the request details to a log file for you to review."""
+    with open(filename,'w') as request_file:
+        request_file.write('{}\n{}\r\n{}\r\n\r\n{}'.format(
+            '-----------START-----------',
+            r.request.method + ' ' + r.request.url,
+            '\r\n'.join('{}: {}'.format(k, v) for k, v in r.request.headers.items()),
+            r.request.body,
+        ))
\ No newline at end of file
