@@ -2,6 +2,8 @@
 
 from enum import Enum
 
+from orijin_sdk.types import Profile, User
+
 class FilterOption(Enum):
 	All = "All"
 	Active = "Active"
@@ -102,9 +104,9 @@ query products(
 
 def me(request_fields = """
 	id
+	email
 	firstName
 	lastName
-	email
 	phone
 	userType
 	isAdmin
@@ -112,9 +114,15 @@ def me(request_fields = """
 	isCustomer
 	# address: Address
 	organization { id }
-	# role: Role
-	# affiliateOrganization: AffiliateOrganization
-	# profile: Profile
+	role { name }
+	affiliateOrganization { organization { id } }
+	profile {
+		referralCode
+		walletPoints
+		dateOfBirth
+		gender
+		createdAt
+	}
 	createdAt
 	# trackActions: [TrackAction!]!
 	isFieldappAccess
@@ -131,4 +139,50 @@ def me(request_fields = """
 
 	variables = {}
 
-	return query, variables
+	def decoder(json_result):
+		try:
+			org_id = json_result["data"]["me"]["organization"]["id"]
+		except:
+			org_id = None
+		
+		try:
+			affiliateOrganization_id = json_result["data"]["me"]["affiliateOrganization"]["organization"]["id"]
+		except:
+			affiliateOrganization_id = None
+		
+		try:
+			profile = Profile(
+				json_result["data"]["me"]["profile"]["referralCode"],
+				json_result["data"]["me"]["profile"]["wallerPoints"],
+				json_result["data"]["me"]["profile"]["dateOfBirth"],
+				json_result["data"]["me"]["profile"]["gender"],
+				json_result["data"]["me"]["profile"]["createdAt"]
+			)
+		except:
+			profile = None
+		
+		try:
+			role_name = json_result["data"]["me"]["role"]["name"]
+		except:
+			role_name = None
+
+		return User(
+			id = json_result["data"]["me"]["id"],
+			email = json_result["data"]["me"]["email"],
+			firstName = json_result["data"]["me"]["firstName"],
+			lastName = json_result["data"]["me"]["lastName"],
+			phone = json_result["data"]["me"]["phone"],
+			userType = json_result["data"]["me"]["userType"],
+			isAdmin = json_result["data"]["me"]["isAdmin"],
+			isMember = json_result["data"]["me"]["isMember"],
+			isCustomer = json_result["data"]["me"]["isCustomer"],
+			organization_id = org_id,
+			role_name = role_name,
+			affiliateOrganization_id = affiliateOrganization_id,
+			profile = profile,
+			createdAt = json_result["data"]["me"]["createdAt"],
+			isFieldappAccess = json_result["data"]["me"]["isFieldappAccess"],
+			isPlatformAccess = json_result["data"]["me"]["isPlatformAccess"],
+		)
+
+	return query, variables, decoder
